@@ -15,6 +15,17 @@ class Parser(ABC):
     For interpretation, it is also supplied with a context.
     """
 
+    blank_node_prefix: str = ''
+
     def as_jsonld_document(self, raw_data: TextIO) -> LDDocument:
         """Generate a JSON-LD document."""
         raise NotImplementedError()
+
+    def as_quad_stream(
+        self,
+        raw_data: TextIO,
+        iri: Optional[URIRef],
+        context: LDContext,
+    ) -> Iterable[Quad]:
+        raise NotImplementedError()
+
