@@ -4,7 +4,7 @@ import yaml
 
 from iolanta.models import LDDocument
 from iolanta.parsers.base import Parser
-from octadocs.octiron.yaml_extensions import convert_dollar_signs
+from iolanta.convert_dollar_signs import convert_dollar_signs
 
 try:  # noqa
     from yaml import CSafeLoader as SafeLoader  # noqa
