@@ -21,121 +21,6 @@ from octadocs.octiron import Octiron
 HTML = URIRef('https://html.spec.whatwg.org/')
 
 
-def find_default_facet_iri_for_environment(ldflex: LDFlex, environment: URIRef):
-    rows = ldflex.query(
-        '''
-        SELECT * WHERE {
-            ?environment iolanta:hasDefaultFacet ?facet .
-        }
-        ''',
-        environment=environment,
-    )
-
-    facets = map(operator.itemgetter('facet'), rows)
-
-    return first(facets, None)
-
-
-def find_explicit_facet(
-    node: Node,
-    ldflex: LDFlex,
-    environment: URIRef,
-):
-    """Find a facet that is explicitly bound to the node."""
-    rows = ldflex.query(
-        '''
-        SELECT ?facet ?environment WHERE {
-            ?node iolanta:facet ?facet .
-            ?facet iolanta:supports ?environment .
-        }
-        ''',
-        node=node,
-        environment=environment,
-    )
-
-    facets = map(operator.itemgetter('facet'), rows)
-
-    if facet := first(facets, None):
-        return facet
-
-
-def find_inferred_facet(
-    node: Node,
-    ldflex: LDFlex,
-    environment: URIRef,
-):
-    """Find facet based on skos:broader relation between environments."""
-    facet = find_explicit_facet(
-        node=node,
-        ldflex=ldflex,
-        environment=environment,
-    )
-
-    if facet is not None:
-        return facet
-
-    broader_environments = map(
-        operator.itemgetter('broader_environment'),
-        ldflex.query(
-            '''
-            SELECT ?broader_environment WHERE {
-                ?environment skos:broader ?broader_environment .
-            }
-            ''',
-            environment=environment,
-        ),
-    )
-
-    for environment in broader_environments:
-        facet = find_explicit_facet(
-            node=node,
-            ldflex=ldflex,
-            environment=environment,
-        )
-
-        if facet is not None:
-            return facet
-
-
-def resolve_literal_type(literal: Literal) -> URIRef:
-    """Resolve literal data type."""
-    if literal.datatype is not None:
-        return literal.datatype
-
-    return RDFS.Literal
-
-
-def find_facet_iri(
-    ldflex: LDFlex,
-    environment: URIRef,
-    node: Node,
-) -> Optional[URIRef]:
-    if isinstance(node, Literal):
-        node = resolve_literal_type(node)
-
-    facet = find_inferred_facet(
-        node=node,
-        ldflex=ldflex,
-        environment=environment,
-    )
-
-    if facet is not None:
-        return facet
-
-    facet = find_default_facet_iri_for_environment(
-        ldflex=ldflex,
-        environment=environment,
-    )
-
-    if facet is None:
-        raise FacetNotFound(
-            node=node,
-            environment=environment,
-        )
-
-    return facet
-
-
 def resolve_facet(iri: URIRef) -> Callable[[Octiron, Node], str]:
     """Resolve a path to a Python object to that object."""
     url = str(iri)
@@ -169,14 +54,17 @@ def resolve_facet(iri: URIRef) -> Callable[[Octiron, Node], str]:
 def render(
     node: Union[str, Node],
     octiron: Octiron,
-    environment: URIRef = HTML,
+    environments: Optional[List[URIRef]] = None,
 ) -> str:
     """Find an Iolanta facet for a node and render it."""
+    if not environments:
+        environments = [HTML]
+
     facet_iri = Render(
         ldflex=octiron.ldflex,
     ).find_facet_iri(
         node=node,
-        environment=environment,
+        environments=environments,
     )
 
     if facet_iri is None:
@@ -190,9 +78,9 @@ def render(
     )
 
     if isinstance(facet, Facet):
-        return facet.render()
+        return str(facet.render())
 
-    return str(facet)
+    return facet
 
 
 @dataclass
@@ -204,8 +92,29 @@ class Render:
     def find_facet_iri(
         self,
         node: Node,
-        environment: URIRef,
+        environments: List[URIRef],
     ) -> URIRef:
+        """Find facet IRI for given node for all environments given."""
+        for environment in environments:
+            try:
+                return self.find_facet_iri_per_environment(
+                    node=node,
+                    environment=environment,
+                )
+            except FacetNotFound:
+                continue
+
+        raise FacetNotFound(
+            node=node,
+            environment=environments[0],
+            node_types=[],
+        )
+
+    def find_facet_iri_per_environment(
+        self,
+        node: Node,
+        environment: URIRef,
+    ):
         """Find facet IRI for given node in given env."""
         if isinstance(node, Literal):
             return self.find_facet_iri_for_literal(
