@@ -6,3 +6,5 @@ class JsonLDDocument(TypedDict):
 
     document: Dict[str, Any]
     contextUrl: Optional[str]
+    documentUrl: str
+    contentType: str
