@@ -16,6 +16,10 @@ class ProvEntity(Facet):
                 ?node
                     prov:value ?value ;
                     prov:wasDerivedFrom ?source .
+
+                OPTIONAL {
+                    ?node rdfs:comment ?comment .
+                }
             }
             ''',
             node=self.iri,
@@ -26,12 +30,16 @@ class ProvEntity(Facet):
         except ValueError:
             return '<prov:value> and <prov:wasDerivedFrom> were not found.'
 
+        kwargs = {}
+        if title := row.get('title'):
+            kwargs.update(title=title)
+
         return a(
             render(
                 node=row['value'],
                 octiron=self.octiron,
-                environment=HTML,
             ),
             href=row['source'],
             target='_blank',
+            **kwargs,
         )
